import {Item} from './data.service'

// pour la démo : items.service et persos.service utilisent fetch alors que towns.service utilise axios.  Les 2 fonctionnent
import {getRequest, patchRequest} from "@/services/fetch.service";

async function getAllItemsFromAPI() {
  return getRequest('/items/get', 'GETALLITEMS')
}

async function getItemByIdFromAPI(id) {
  return getRequest('/items/getbyid/'+id, 'GETITEMBYID')
}

async function getItemByNameFromAPI(name) {
  return getRequest('/items/getbyname/'+name, 'GETITEMBYNAME')
}

async function updateItemPriceFromAPI(id, price) {
  let data = {
    id: id,
    price: price,
  }
  return patchRequest('/items/updateprice', data, 'UPDATEITEMPRICE')
}

async function getAllItems() {
  // result est ce qui est renoyvé par getallCharacs()
  let result = {error: 0, status: 200, data: null}
  // response est ce qui est renvoyé par axiosAgent
  let response = await getAllItemsFromAPI()
  // test si la requête a réussi et si oui, conversion du format des données.
  // NB : pour la liste des villes, il ne devrait jamais y avoir d'erreur. Au pire,
  // on obtient un tableau vide.
  if (response.error === 0) {
    // les données de la réponse sont un tableau contenant les personnage
    let items = []
    response.data.forEach(i => items.push(Item.fromAPI(i)))
    result.data = items
  }
  else {
    result = response
  }
  return result
}

async function getItemById(id) {
  // result est ce qui est renoyvé par getallCharacs()
  let result = {error: 0, status: 200, data: null}
  // response est ce qui est renvoyé par axiosAgent
  let response = await getItemByIdFromAPI(id)
  // test si la requête a réussi et si oui, conversion du format des données.
  // NB : pour la liste des villes, il ne devrait jamais y avoir d'erreur. Au pire,
  // on obtient un tableau vide.
  if (response.error === 0) {
    // la réponse est convertie en un objet local
    result.data = Item.fromAPI(response.data)
  }
  else {
    result = response
  }
  return result
}

async function getItemByName(name) {
  // result est ce qui est renoyvé
  let result = {error: 0, status: 200, data: null}
  // response est ce qui est renvoyé par axiosAgent
  let response = await getItemByNameFromAPI(name)
  // test si la requête a réussi et si oui, conversion du format des données.
  // NB : pour la liste des villes, il ne devrait jamais y avoir d'erreur. Au pire,
  // on obtient un tableau vide.
  if (response.error === 0) {
    // la réponse est convertie en un objet local
    result.data = Item.fromAPI(response.data)
  }
  else {
    result = response
  }
  return result
}

async function updateItemPrice(id, price) {
  // result est ce qui est renvoyé
  let result = {error: 0, status: 200, data: null}
  // response est ce qui est renvoyé par axiosAgent
  let response = await updateItemPriceFromAPI(id, price)
  // test si la requête a réussi et si oui, conversion du format des données.
  // NB : pour la liste des villes, il ne devrait jamais y avoir d'erreur. Au pire,
  // on obtient un tableau vide.
  if (response.error === 0) {
    // la réponse est convertie en un objet local
    result.data = Item.fromAPI(response.data)
  }
  else {
    result = response
  }
  return result
}

export {
  getAllItems,
  getItemById,
  getItemByName,
  updateItemPrice,
}