import Vue from 'vue'
import Vuex from 'vuex'

import {getAllCharacs} from "@/services/persos.service";
import {getAllTowns} from "@/services/towns.service";
import {getAllItems, getItemById, getItemByName, updateItemPrice} from "@/services/items.service";

Vue.use(Vuex)

export default new Vuex.Store({
  state: {
    villes: [],
    persos: [],
    items: [],
    currentItem: null,
  },
  getters: {
  },
  mutations: {
    setVilles(state, villes) {
      state.villes.splice(0)
      villes.forEach(t => state.villes.push(t))
    },
    resetVilles(state) {
      state.villes.splice(0)
    },
    setPersos(state, persos) {
      state.persos.splice(0)
      persos.forEach(p => state.persos.push(p))
    },
    resetPersos(state) {
      state.persos.splice(0)
    },
    setItems(state, items) {
      state.items.splice(0)
      items.forEach(i => state.items.push(i))
    },
    resetItems(state) {
      state.items.splice(0)
    },
    setCurrentItem(state, item) {
      state.currentItem = item
    },
    setCurrentItemPrice(state, price) {
      state.currentItem.prix = price
    },
    updateItem(state, item) {
      // remplace l'item dans items, dont l'id correspond à item._id fournit en paramètre
      let idx = state.items.findIndex(e => e._id === item._id)
      if (idx !== -1) {
        state.items.splice(idx,1,item)
      }
    }
  },
  actions: {
    async getPersosFromAPI({commit}) {
      let result = null
      try {
        result = await getAllCharacs()
        if (result.error === 0) {
          commit('setPersos',result.data)
        }
        else {
          console.log(result.data)
        }
      }
      catch(err) {
        console.log("Cas anormal dans getPersosFromAPI()")
      }
    },
    async getVillesFromAPI({commit}) {
      let result = null
      try {
        result = await getAllTowns()
        if (result.error === 0) {
          commit('setVilles',result.data)
        }
        else {
          console.log(result.data)
        }
      }
      catch(err) {
        console.log("Cas anormal dans getVillesFromAPI()")
      }
    },
    async getItemsFromAPI({commit}) {
      let result = null
      try {
        result = await getAllItems()
        if (result.error === 0) {
          commit('setItems',result.data)
        }
        else {
          console.log(result.data)
        }
      }
      catch(err) {
        console.log("Cas anormal dans getItemsFromAPI()")
      }
    },
    async getItemByIdFromAPI({commit}, id) {
      let result = null
      try {
        result = await getItemById(id)
        if (result.error === 0) {
          commit('setCurrentItem',result.data)
        }
        else {
          console.log(result.data)
        }
      }
      catch(err) {
        console.log("Cas anormal dans getItemByIdFromAPI()")
      }
    },
    async getItemByNameFromAPI({commit}, name) {
      let result = null
      try {
        result = await getItemByName(name)
        if (result.error === 0) {
          commit('setCurrentItem',result.data)
        }
        else {
          console.log(result.data)
        }
      }
      catch(err) {
        console.log("Cas anormal dans getItemByNameFromAPI()")
      }
    },
    async updateCurrentItemPriceToAPI({state, commit}, price) {
      let result = null
      try {
        result = await updateItemPrice(state.currentItem._id, price)
        if (result.error === 0) {
          // change juste le prix de l'item courant
          commit('setCurrentItemPrice',price)
          // change le prix de l'item dans le tableau items, mais en remplaçant complètement l'item
          // avec celui reçu de l'API (=> pas besoin d'une autre mutation)
          commit('updateItem',result.data)
        }
        else {
          console.log(result.data)
        }
      }
      catch(err) {
        console.log("Cas anormal dans updateCurrentItemPriceToAPI()")
      }
    },
  },
  modules: {
  }
})
